@@ -1,6 +1,6 @@
 #!/bin/bash
 
-mversion="V5.1"
+mversion="V6.1"
 
 modulesdir=usr/lib/asterisk/modules
 soundsdir=var/lib/asterisk
@@ -17,6 +17,9 @@ dst=
 #src=asterisk_$mversion
 #dst=/tmp/asterisk_$mversion
 
+echo "Stopping Openvxi.."
+/etc/init.d/openvxi stop
+
 echo "Removing binaries..."
 rm -f $dst/usr/sbin/openvxi
 rm -f $dst/usr/sbin/adminvxi
@@ -75,6 +78,7 @@ rm -f $dst/$soundsdir/silence.raw
 echo "Removing directories..."
 rm -rf $dst/usr/lib/openvxi
 rm -rf $dst/etc/openvxi
+rm -rf $dst/var/lib/openvxi
 
 echo "--- VXIasterisk $mversion remove has finished ---"
 
